using System.ComponentModel;
using System.Reflection;
using GraphicsManager;
using GraphicsManager.Enums;
using GraphicsManager.Interfaces;
using GraphicsManager.Objects;
using GraphicsManager.Objects.Core;
using Luski.GUI.MainScreen.Interfaces;
using Luski.GUI.MainScreen.UI;
using Luski.GUI.StartPage.UI;
using Luski.net;
using Luski.net.JsonTypes;
using OpenTK.Graphics.OpenGL4;
using OpenTK.Mathematics;
using OpenTK.Windowing.Desktop;
using OpenTK.Windowing.Common;

namespace Luski.GUI.MainScreen;

public class MainScreen : Window
{
    private static readonly NativeWindowSettings Settings = new()
    {
        Title = "Luski Login",
        WindowBorder = WindowBorder.Fixed,
        APIVersion = new Version(3, 2),
        StartFocused = true,
        Size = new OpenTK.Mathematics.Vector2i(481, 838),
    };
    FlowLayout? channelpicker;
    
    public MainScreen() : base(Settings)
    {
        Login login;
        Controls.Add(login = new Login());
        login.ChangeToApp += LoginOnChangeToApp;
    }

    public void AddGroup(SocketGroupChannel group)
    {
        Group friend = new(group);
        friend.ClickCon += ChannelOnClickCon;
        channelpicker!.Controls.Add(friend);
        chans.Add(friend);
    }

    private readonly List<Friend> fr = new();
    private List<IChannelPick> chans = new();
    public void AddFriend(SocketRemoteUser user)
    {
        //add to friend pannel as well;
        if (user.Channel is not null)
        {
            Friend friend = new(user);
            friend.ClickCon += ChannelOnClickCon;
            fr.Add(friend);
            channelpicker!.Controls.Add(friend);
            chans.Add(friend);
        }
    }

    private Task ChannelOnClickCon(IChannelPick arg)
    {
        //show their channel
        return Task.CompletedTask;
    }

    private Task LoginOnChangeToApp()
    {
        Controls.Clear();
        Title = "Luski";
        Size = new(2048, 1334);
        WindowBorder = WindowBorder.Resizable;
        BackgroundColor = new Color4(34, 34, 34, 255);
        Controls.Add(new Rectangle(new Texture(Globals.Luski.CurrentUser.GetAvatar().Result)) { Size = new(70, 70), Location = new(146, 78 + 1170)});
        Controls.Add(new Label(){Location = new(132 + 92, 39 + 62+1170), Text = Globals.Luski.CurrentUser.Username});
        
        Controls.Add(channelpicker = new FlowLayout()
        {
            BackgroundColor = new(34,34,34,255),
            Size = new(448, 1240),
            Location = new(132, 0),
            Anchor = ObjectAnchor.Top | ObjectAnchor.Left | ObjectAnchor.Bottom
        });
        foreach (SocketGroupChannel ch in Globals.Luski.CurrentUser.Channels.Where(s => s is SocketGroupChannel).Cast<SocketGroupChannel>())
        {
            AddGroup(ch);
        }
        foreach (SocketRemoteUser item in Globals.Luski.CurrentUser.Friends)
        {
            if (item.Channel is not null) AddFriend(item);
        }
        DrawFrame();
        return Task.CompletedTask;
    }
}